@@ -16,13 +16,13 @@ use TextTableTiny 'generate_markdown_table';
 
 # ABSTRACT: TopCount and related methods for Vote::Count. Toolkit for vote counting.
 
-our $VERSION='0.017';
+our $VERSION='0.021';
 
 =head1 NAME
 
 Vote::Count::TopCount
 
-=head1 VERSION 0.017
+=head1 VERSION 0.021
 
 =head1 Synopsis
 
@@ -43,7 +43,8 @@ Returns a RankCount object containing the TopCount.
 sub TopCount ( $self, $active=undef ) {
   my %ballotset = $self->BallotSet()->%*;
   my %ballots = ( $ballotset{'ballots'}->%* );
-  $active = $ballotset{'choices'} unless defined $active ;
+  # $active = $ballotset{'choices'} unless defined $active ;
+  $active = $self->Active() unless defined $active ;
   my %topcount = ( map { $_ => 0 } keys( $active->%* ));
 TOPCOUNTBALLOTS:
     for my $b ( keys %ballots ) {
@@ -71,6 +72,7 @@ Returns a hashref of results. It will always include the votes in the round and
 =cut
 
 sub TopCountMajority ( $self, $topcount = undef, $active = undef ) {
+  $active = $self->Active() unless defined $active;
   unless ( defined $topcount ) { $topcount = $self->TopCount($active) }
   my $topc = $topcount->RawCount();
   my $numvotes = $topcount->CountVotes();
